Configuration documents for BioBlend — BioBlend 0.5.4-dev documentation

# Configuration documents for BioBlend

## BioBlend

class `bioblend.` `NullHandler`(level=0)

  Initializes the instance - basically setting the formatter to None and the filter list to empty.

  `emit`(record)

`bioblend.` `get_version`()

  Returns a string with the current version of the library (e.g., “0.2.0”)

`bioblend.` `init_logging`()

  Initialize BioBlend’s logging from a configuration file.

`bioblend.` `set_file_logger`(name, filepath, level=20, format_string=None)

`bioblend.` `set_stream_logger`(name, level=10, format_string=None)

## Config

class `bioblend.config.` `Config`(path=None, fp=None, do_load=True)

  BioBlend allows library-wide configuration to be set in external files. These configuration files can be used to specify access keys, for example. By default we use two locations for the BioBlend configurations:

  - System wide: `/etc/bioblend.cfg`
  - Individual user: `~/.bioblend` (which works on both Windows and Unix)
  `get`(section, name, default=None)
  `get_value`(section, name, default=None)
  `getbool`(section, name, default=False)
  `getfloat`(section, name, default=0.0)
  `getint`(section, name, default=0)